@@ -168,13 +168,12 @@ int main(argc, argv)
   int offs_x, offs_y, new_x, new_y, tmp_x, tmp_y;
   unsigned int tmp_mask;
 
-  teddy.teddy = argv[0]; 
-
   /* Determine program name */
   if ((progname = strrchr(argv[0],'/')) == NULL)
     progname = argv[0];
   else
     progname++;
+  teddy.teddy = progname; 
 
   /* Option handling: "-wm", "-float", "-noquit", "-mono", "-geometry" */
   /* and "-display" are recognized. See manual page for details. */
